( cd usr/lib ; rm -rf libaal.so )
( cd usr/lib ; ln -sf libaal-1.0.so.5.0.0 libaal.so )
( cd usr/lib ; rm -rf libaal-1.0.so.5 )
( cd usr/lib ; ln -sf libaal-1.0.so.5.0.0 libaal-1.0.so.5 )
( cd usr/lib ; rm -rf libaal-minimal.so )
( cd usr/lib ; ln -sf libaal-minimal.so.0.0.0 libaal-minimal.so )
( cd usr/lib ; rm -rf libaal-minimal.so.0 )
( cd usr/lib ; ln -sf libaal-minimal.so.0.0.0 libaal-minimal.so.0 )
